@@ -1,6 +1,7 @@
 package helper;
 
 use Test::More;
+use urpm::select;
 use urpm::util;
 use base 'Exporter';
 our @EXPORT = qw(need_root_and_prepare need_downloader
@@ -176,8 +177,7 @@ sub check_installed_and_urpme {
 }
 
 sub are_weak_deps_supported() {
-    # CentOS 7 doesn't support weak deps tags (it only knows their definitions):
-    cat_('/etc/redhat-release' =~ /^CentOS Linux release 7/);
+    return urpm::select::_rpm_version() gt 4.12.0
 }
 
 END { 
